@@ -5,6 +5,7 @@ from sklearn.model_selection import train_test_split
 from sklearn.multiclass import OneVsRestClassifier
 
 from omnixai.explainers.prediction import PredictionAnalyzer
+from omnixai.explanations.base import ExplanationBase
 
 
 class TestPrecisionRecall(unittest.TestCase):
@@ -38,6 +39,11 @@ class TestPrecisionRecall(unittest.TestCase):
         explanations.plot()
         explanations.plotly_plot()
 
+        s = explanations.to_json()
+        e = ExplanationBase.from_json(s)
+        self.assertEqual(s, e.to_json())
+        e.plotly_plot()
+
 
 if __name__ == "__main__":
     unittest.main()
